from setuptools import setup, find_packages

setup(
    name="teleos",
    version="0.0.1",
    description="Package under development",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Your Name",
    author_email="walletday@gmx.com",
    packages=find_packages(),
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 1 - Planning",
        "Programming Language :: Python :: 3",
    ],
)
